==> haskell-interpolatedstring-perl6-1.0.2-313-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-93z40nbHKuPEDM8w4PTUJO
key:                  interpolatedstring-perl6-1.0.2-93z40nbHKuPEDM8w4PTUJO
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  8af28b996e01224890c64dee6257bcd6
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-93z40nbHKuPEDM8w4PTUJO
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    haskell-src-meta-0.8.14-CKoODPu7eIyHmLSF857pJH
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolatedstring-perl6-1.0.2-314-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-4BcKF4zzj6x4yvaCSWXmt3
key:                  interpolatedstring-perl6-1.0.2-4BcKF4zzj6x4yvaCSWXmt3
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  daba1d1a3de34665b84c12b942f86e0a
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-4BcKF4zzj6x4yvaCSWXmt3
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    haskell-src-meta-0.8.14-1six67SZmHc8alzSueF00c
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
